VersionSentryInfo class
Constructors
- VersionSentryInfo({required String platform, required String currentVersion, required String storeVersion, required bool needsUpdate, required bool isMajorUpdate, required bool isMinorUpdate, required bool isPatchUpdate, String? releaseNotes, required String packageName, required String bundleId, required String appUpdateLink})
-
VersionSentryInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appUpdateLink → String
-
final
- bundleId → String
-
final
- currentVersion → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMajorUpdate → bool
-
final
- isMinorUpdate → bool
-
final
- isPatchUpdate → bool
-
final
- needsUpdate → bool
-
final
- packageName → String
-
final
- platform → String
-
final
- releaseNotes → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storeVersion → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited